/* dialog.cpp
 *
 * Pieter Eendebak <pte@ddsw.nl>
 *
 */

#include "includes.h"
#include "defines.h"
#include "cube.h"

#include <kcolorbtn.h>

#include "dialog.moc"

Kleur::Kleur ( QWidget *parent, const char *name )
                : QDialog ( parent, name, TRUE )
{
	setCaption(CAPTION);

	int breed= 270;
	int hoog= 473 ;

	setFixedSize(breed, hoog);

	const int bbreed=breed-20;
	const int bhoog=hoog-60;

	box = new QGroupBox(klocale->translate("Configure colors"),
			this,
			"box" );
	int i;
	QString tmp;
	const int aantal=6;

	blabel = new QLabel(
		klocale->translate("Background"),
		box );
	background = new KColorButton(box, 0 );

	elabel = new QLabel(
		klocale->translate("Edges"),
		box );
	edge = new KColorButton(box, 0);

	naam = new QLabel *[aantal];
	kleur = new KColorButton *[aantal];

	for(i=0;i<aantal;i++)
	{
		tmp.sprintf("%s %d ",
			klocale->translate("Color"),
			i );
		naam[i]=new QLabel(tmp.data(), box);
		kleur[i]=new KColorButton(box, 0 );
	}

	line = new QFrame( box );
	line->setLineWidth(1);
	line->setFrameStyle( QFrame::Sunken | QFrame::HLine );

	shade = new QCheckBox(	klocale->translate("Use shading"),
				box,
				"shade" );
	connect( shade, SIGNAL( toggled(bool)),
			this, SLOT( leveltoggle(bool)) ) ;
	level = new QLabel( klocale->translate("Shading level :"),
				box,
				"level" ) ;
	levelbar = new QScrollBar(0, 10, 1, 1, 0,
				QScrollBar::Horizontal, box,
				"levelbar");
	levelcounter = new QLabel("5", box, "levelcounter");
	levelcounter->setFrameStyle( QFrame::Panel | QFrame::Sunken);
	levelcounter->setAlignment(AlignCenter);	
	connect( levelbar, SIGNAL( valueChanged(int)),
		 this, SLOT( levelchange(int)) );
	connect( levelbar, SIGNAL( valueChanged(int)),
		levelcounter, SLOT( setNum(int)) ) ;

	ok = new QPushButton(klocale->translate("Ok"), this, "ok");
	cancel = new QPushButton(klocale->translate("Cancel"),
			 this,
			 "cancel");
	connect(ok, SIGNAL(clicked()), this, SLOT(accept()) );
	connect(cancel, SIGNAL(clicked()), this, SLOT(reject()) );

	
	// setup the widget
	box->setGeometry(10,10, bbreed, bhoog);

	blabel->setGeometry(20, 30, 80, 30);
	background->setGeometry(140, 30, 55, 30);
	elabel->setGeometry(20, 65, 80, 30);
	edge->setGeometry(140, 65, 55, 30);

	for(i=0;i<aantal;i++)
	{
		naam[i]->setGeometry(20,100+35*i,80,30);
		kleur[i]->setGeometry(140, 100+35*i, 55, 30 );
	}

	line->setGeometry(10, 105+aantal*35, bbreed-20, 4 );

	const int offset = 110+aantal*35 ;
	shade->setGeometry(20, offset, bbreed-40, 30 );
	level->setGeometry(20, offset+25, bbreed-40, 30 );
	levelcounter->setGeometry( bbreed - (20+16) , offset+32, 16, 16 );
	levelbar->setGeometry(20, offset+60, bbreed-40, 13 );

	ok->setGeometry(breed-160, hoog-40, 70, 30);
	cancel->setGeometry(breed-80, hoog-40, 70, 30);

	shade->setEnabled( true ) ;
	levelbar->setValue( 5 ) ;
}

void Kleur::leveltoggle( bool )
{
	if ( shade->isChecked() )
	{
		levelbar->setEnabled( true ) ;
		levelcounter->setEnabled( true ) ;
	}
	else
	{
		levelbar->setEnabled( false ) ;
		levelcounter->setEnabled( false ) ;
	}
}

void Kleur::levelchange( int _level )
{
	l = _level ;
}

int Kleur::getShading()
{
	if ( shade->isChecked() )
	{
		return l ;
	}
	else	return Cube::NO_SHADE ;
}

Kleur::~Kleur()
{

	delete blabel;
	delete background;
	delete elabel;
	delete edge;
	delete [] naam;
	delete [] kleur;
	delete line;
	delete shade;
	delete level ;
	delete levelcounter ;
	delete levelbar ;

	delete box;
	
	delete ok;
	delete cancel;
}
